package com.sun.media.sound;

import java.io.File;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.InputStream;
import javax.sound.midi.InvalidMidiDataException;
import javax.sound.sampled.AudioInputStream;
import java.io.IOException;
import javax.sound.sampled.UnsupportedAudioFileException;
import javax.sound.sampled.AudioSystem;
import javax.sound.midi.Soundbank;
import java.net.URL;
import javax.sound.midi.spi.SoundbankReader;

public final class AudioFileSoundbankReader extends SoundbankReader
{
    public AudioFileSoundbankReader() {
    }
    
    @Override
    public Soundbank getSoundbank(URL url) throws InvalidMidiDataException, IOException {
        try {
            AudioInputStream audioInputStream = AudioSystem.getAudioInputStream(url);
            Soundbank soundbank = this.getSoundbank(audioInputStream);
            audioInputStream.close();
            return soundbank;
        }
        catch (UnsupportedAudioFileException ex) {
            return null;
        }
        catch (IOException ex2) {
            return null;
        }
    }
    
    @Override
    public Soundbank getSoundbank(InputStream stream) throws InvalidMidiDataException, IOException {
        stream.mark(512);
        try {
            Soundbank soundbank = this.getSoundbank(AudioSystem.getAudioInputStream(stream));
            if (soundbank != null) {
                return soundbank;
            }
        }
        catch (UnsupportedAudioFileException ex) {}
        catch (IOException ex2) {}
        stream.reset();
        return null;
    }
    
    public Soundbank getSoundbank(AudioInputStream in) throws InvalidMidiDataException, IOException {
        try {
            byte[] byteArray;
            if (in.getFrameLength() == -1L) {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                byte[] array = new byte[1024 - 1024 % in.getFormat().getFrameSize()];
                int read;
                while ((read = in.read(array)) != -1) {
                    byteArrayOutputStream.write(array, 0, read);
                }
                in.close();
                byteArray = byteArrayOutputStream.toByteArray();
            }
            else {
                byteArray = new byte[(int)(in.getFrameLength() * (long)in.getFormat().getFrameSize())];
                new DataInputStream(in).readFully(byteArray);
            }
            ModelByteBufferWavetable o = new ModelByteBufferWavetable(new ModelByteBuffer(byteArray), in.getFormat(), -4800.0f);
            ModelPerformer o2 = new ModelPerformer();
            o2.getOscillators().add(o);
            SimpleSoundbank o3 = new SimpleSoundbank();
            SimpleInstrument o4 = new SimpleInstrument();
            o4.add(o2);
            o3.addInstrument(o4);
            return o3;
        }
        catch (Exception ex) {
            return null;
        }
    }
    
    @Override
    public Soundbank getSoundbank(File file) throws InvalidMidiDataException, IOException {
        try {
            AudioSystem.getAudioInputStream(file).close();
            ModelByteBufferWavetable modelByteBufferWavetable = new ModelByteBufferWavetable(new ModelByteBuffer(file, 0L, file.length()), -4800.0f);
            ModelPerformer modelPerformer = new ModelPerformer();
            modelPerformer.getOscillators().add(modelByteBufferWavetable);
            SimpleSoundbank simpleSoundbank = new SimpleSoundbank();
            SimpleInstrument simpleInstrument = new SimpleInstrument();
            simpleInstrument.add(modelPerformer);
            simpleSoundbank.addInstrument(simpleInstrument);
            return simpleSoundbank;
        }
        catch (UnsupportedAudioFileException ex) {
            return null;
        }
        catch (IOException ex2) {
            return null;
        }
    }
}
